@@ -1,11 +1,11 @@
 package Workflow::Condition;
 
-# $Id: Condition.pm,v 1.5 2006/07/08 20:02:33 jonasbn Exp $
+# $Id: Condition.pm,v 1.6 2006/09/12 17:59:30 jonasbn Exp $
 
 use strict;
 use base qw( Workflow::Base );
 
-$Workflow::Condition::VERSION  = sprintf("%d.%02d", q$Revision: 1.5 $ =~ /(\d+)\.(\d+)/);
+$Workflow::Condition::VERSION  = sprintf("%d.%02d", q$Revision: 1.6 $ =~ /(\d+)\.(\d+)/);
 
 my @FIELDS = qw( name class );
 __PACKAGE__->mk_accessors( @FIELDS );
@@ -45,13 +45,17 @@ Workflow::Condition - Evaluate a condition depending on the workflow state and e
    </condition>
  ...
  
- # Reference the condition in an action...
- <actions>
-    <action name="MyAction" class="My::Action">
-      ... 
-      <condition name="IsAdminUser" />
-    </action>
- ...
+ # Reference the condition in an action of the state/workflow definition...
+ <workflow>
+   <state>
+     ...
+     <action name="MyAction">
+       ... 
+       <condition name="IsAdminUser" />
+     </action>
+   </state>
+   ...
+ </workflow>
   
  # Then implement the condition
  
@@ -94,6 +98,13 @@ available in a particular context. So if user A asks the workflow for
 the available actions she might get a different answer than user B
 since they determine separate contexts.
 
+B<NOTE>: The condition is enforced by Workflow::State. This means that
+the condition name must be visible inside of the state definition. If
+you specify the reference to the condition only inside of the full
+action specification in a seperate file then nothing will happen. The
+reference to the condition must be defined inside of the state/workflow
+specification.
+
 =head1 SUBCLASSING
 
 =head2 Strategy
